@@ -7,7 +7,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK);
 use base 'Exporter';
 @EXPORT_OK = @EXPORT = qw( hash2xml xml2hash );
 
-$VERSION = '0.55';
+$VERSION = '0.56';
 
 require XSLoader;
 XSLoader::load('XML::Hash::XS', $VERSION);
@@ -224,11 +224,11 @@ if defined that the key name for the text content(used only if use_attr=1).
 
 =item force_array => [ = undef ] I<# xml2hash>
 
-This option is similar to "ForceArray" from XMl::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceArray-=%3E-1-%23-in-important>.
+This option is similar to "ForceArray" from XML::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceArray-=%3E-1-%23-in-important>.
 
 =item force_content => [ = 0 ] I<# xml2hash>
 
-This option is similar to "ForceContent" from XMl::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceContent-=%3E-1-%23-in-seldom-used>.
+This option is similar to "ForceContent" from XML::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceContent-=%3E-1-%23-in-seldom-used>.
 
 =item merge_text [ = 0 ] I<# xml2hash>
 
@@ -412,7 +412,7 @@ Yuriy Ustushenko, E<lt>yoreek@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2020 Yuriy Ustushenko
+Copyright (C) 2012-2021 Yuriy Ustushenko
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
